//---------------------------------------------------------------------------
// File: TMainForm.h
//
//  TDx_Sound_Library
//  ExampleA - Capturing Sounds
//
// Date: 9th January, 2004
// Last Updated: 21st May 2013
// Author: Darren John Dwyer
// Copyright: (c) 2002-2013 Darren John Dwyer, All Rights Reserved.
//
// Description:
//
// This example shows how to enumerate DirectSoundCapture recording devices,
// then create either the default device, or any particular recording device,
// then record sound using this device,
// and then playback the recording through an identical format sound output buffer,
// copying the data directly from the sound capture buffer to the sound buffer.
//
//---------------------------------------------------------------------------
#ifndef Unit1H
#define Unit1H
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
//---------------------------------------------------------------------------
#include "TDx_Sound.h"
#include "TDx_SoundCapture.h"
#include "TDx_SoundCaptureBuffer.h"
#include "TDSCBufferDesc.h"
#include "TDx_SoundBuffer.h"
#include "TDSBufferDesc.h"
#include <vcl\Buttons.hpp>
#include <vcl\ExtCtrls.hpp>
//---------------------------------------------------------------------------
#if (__BORLANDC__ < 0x0530) // BCB Version 1
class TMainForm : public TForm
{
#else // BCB Version 3 or 4
class PACKAGE TMainForm : public TForm
{
#endif
//---------------------------------------------------------------------------
__published:// Anything that is to be displayed within the Object Inspector
//---------------------------------------------------------------------------
    TDx_SoundCapture *Dx_SoundCapture1;
    TDx_SoundCaptureBuffer *Dx_SoundCaptureBuffer1;
    TDSCBufferDesc *DSCBufferDesc1;
    TDx_Sound *Dx_Sound1;
    TDx_SoundBuffer *Dx_SoundBuffer1;
    TDSBufferDesc *DSBufferDesc1;
    TPanel *Panel5;
    TLabel *Label4;
    TBitBtn *ExitButton;
    TPanel *Panel1;
    TLabel *Label5;
    TMemo *InfoMemo;
    TPanel *Panel2;
    TLabel *Label3;
    TMemo *StatusMemo;
    TBitBtn *ClearButton;
    TButton *RecordButton;
    TButton *StopButton;
    TButton *PlaybackButton;
    TPanel *Panel3;
    TLabel *Label7;
    TListBox *DevicesListBox;
    TPanel *Panel4;
    TLabel *Label1;
    TRadioGroup *NumChannelsRadioGroup;
    TRadioGroup *FrequencyRadioGroup;
    TRadioGroup *BitsRadioGroup;
    TButton *Button1;
    TLabel *Label8;
    TLabel *StatusLabel;
    TLabel *Label10;
    TLabel *TotalSecondsLabel;
    TScrollBar *SecondsScrollBar;
    TLabel *SecondsLabel;
    TLabel *Label2;
    TButton *StopPlayButton;
    TButton *Button2;
    void __fastcall Dx_SoundCapture1Create(TObject *Sender);
    void __fastcall Dx_SoundCapture1Destroy(TObject *Sender);
    void __fastcall Dx_SoundCaptureBuffer1Error(TObject *Sender,
    AnsiString Function, AnsiString Error, AnsiString ErrorMessage);
    void __fastcall RecordButtonClick(TObject *Sender);
    void __fastcall StopButtonClick(TObject *Sender);
    void __fastcall PlaybackButtonClick(TObject *Sender);
    void __fastcall Dx_Sound1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage);
    void __fastcall Dx_SoundBuffer1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage);
    void __fastcall Dx_SoundCapture1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage);
    void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
    void __fastcall Dx_SoundCaptureBuffer1Create(TObject *Sender);
    void __fastcall Dx_SoundCaptureBuffer1Destroy(TObject *Sender);
    void __fastcall Dx_Sound1Create(TObject *Sender);
    void __fastcall Dx_Sound1Destroy(TObject *Sender);
    void __fastcall Dx_SoundBuffer1BufferLost(TObject *Sender);
    void __fastcall Dx_SoundBuffer1Create(TObject *Sender);
    void __fastcall Dx_SoundBuffer1Destroy(TObject *Sender);
    
    void __fastcall Dx_SoundCapture1DSCaptureEnumerate(TObject *Sender,
          GUID *Guid, AnsiString DriverDescription,
          AnsiString DriverModule, void *Context, bool &Finished);
    void __fastcall ClearButtonClick(TObject *Sender);
    void __fastcall DevicesListBoxClick(TObject *Sender);
    void __fastcall SecondsScrollBarChange(TObject *Sender);
    void __fastcall ExitButtonClick(TObject *Sender);
    void __fastcall FormCreate(TObject *Sender);

    void __fastcall Button1Click(TObject *Sender);
    
    
    
    void __fastcall StopPlayButtonClick(TObject *Sender);
    void __fastcall Button2Click(TObject *Sender);
    void __fastcall Button3Click(TObject *Sender);
    
public:        // Anything available to other classes and/or code
    __fastcall TMainForm(TComponent* Owner);
    virtual __fastcall ~TMainForm();

//---------------------------------------------------------------------------
protected:  // Anything available only to classes descended from this class
//---------------------------------------------------------------------------
private:    // Private data not accessible except from this class

    #define MAX_DEVICES_SUPPORTED     10

    int         NumCaptureDevices;

    GUID*       Guids[MAX_DEVICES_SUPPORTED];
    AnsiString  DriverDescriptions[MAX_DEVICES_SUPPORTED];
    AnsiString  DriverModules[MAX_DEVICES_SUPPORTED];

    // used for creating the required format sound input device
    WAVEFORMATEX    WaveFormat;
};
//---------------------------------------------------------------------------
#if (__BORLANDC__ < 0x0530) // BCB Version 1
extern TMainForm *MainForm;
#else // BCB Version 3 or 4
extern PACKAGE TMainForm *MainForm;
#endif
//---------------------------------------------------------------------------
#endif
